import { TTimerType } from '../types';

export interface ISetNotification {
    id: null;

    method: 'set';

    params: {
        delay: number;

        now: number;

        timerId: number;

        timerType: TTimerType;
    };
}
