import { TTimerType } from '../types';
export interface IClearRequest {
    id: number;
    method: 'clear';
    params: {
        timerId: number;
        timerType: TTimerType;
    };
}
//# sourceMappingURL=clear-request.d.ts.map