import { ICallNotification, IClearResponse, IErrorNotification, IErrorResponse } from '../interfaces';
export type TWorkerMessage = ICallNotification | IClearResponse | IErrorNotification | IErrorResponse;
//# sourceMappingURL=worker-message.d.ts.map