export declare const clearScheduledInterval: (timerId: number) => void;
export declare const clearScheduledTimeout: (timerId: number) => void;
export declare const scheduleInterval: (delay: number, timerId: number, nowInMainThread: number) => void;
export declare const scheduleTimeout: (delay: number, timerId: number, nowInMainThread: number) => void;
//# sourceMappingURL=timer.d.ts.map